@@ -30,7 +30,7 @@ class Jenkins(JenkinsBase):
     """
     Represents a jenkins environment.
     """
-    def __init__(self, baseurl, username=None, password=None, requester=None):
+    def __init__(self, baseurl, username=None, password=None, requester=None, lazy=False):
         """
         :param baseurl: baseurl for jenkins instance including port, str
         :param username: username for jenkins auth, str
@@ -40,7 +40,12 @@ class Jenkins(JenkinsBase):
         self.username = username
         self.password = password
         self.requester = requester or Requester(username, password, baseurl=baseurl)
-        JenkinsBase.__init__(self, baseurl)
+        self.lazy = lazy
+        JenkinsBase.__init__(self, baseurl, poll=not lazy)
+
+    def _poll_if_needed(self):
+        if self.lazy and self._data is None:
+            self.poll()
 
     def _clone(self):
         return Jenkins(self.baseurl, username=self.username,
@@ -92,6 +97,7 @@ class Jenkins(JenkinsBase):
         """
         Fetch all the build-names on this Jenkins server.
         """
+        self._poll_if_needed()
         for info in self._data["jobs"]:
             yield info["name"], \
                 Job(info["url"], info["name"], jenkins_obj=self)
@@ -101,6 +107,7 @@ class Jenkins(JenkinsBase):
         Get the jobs information
         :return url, name
         """
+        self._poll_if_needed()
         for info in self._data["jobs"]:
             yield info["url"], info["name"]
 
@@ -123,6 +130,9 @@ class Jenkins(JenkinsBase):
     def create_job(self, jobname, config_):
         """
         Create a job
+
+        alternatively you can create job using Jobs object:
+        self.jobs['job_name'] = config
         :param jobname: name of new job, str
         :param config: configuration of new job, xml
         :return: new Job obj
@@ -159,6 +169,7 @@ class Jenkins(JenkinsBase):
         return self.jobs.rename(jobname, newjobname)
 
     def iterkeys(self):
+        self._poll_if_needed()
         for info in self._data["jobs"]:
             yield info["name"]
 
@@ -189,7 +200,7 @@ class Jenkins(JenkinsBase):
         return Views(self)
 
     def get_view_by_url(self, str_view_url):
-        #for nested view
+        # for nested view
         str_view_name = str_view_url.split('/view/')[-1].replace('/', '')
         return View(str_view_url, str_view_name, jenkins_obj=self)
 
@@ -205,12 +216,15 @@ class Jenkins(JenkinsBase):
         :param jobname: name of job, str
         :return: Job obj
         """
+        self._poll_if_needed()
+
         for info in self._data["jobs"]:
             if info["name"] == jobname:
                 return Job(info["url"], info["name"], jenkins_obj=self)
         raise UnknownJob(jobname)
 
     def __len__(self):
+        self._poll_if_needed()
         return len(self._data["jobs"])
 
     def __contains__(self, jobname):
@@ -221,6 +235,9 @@ class Jenkins(JenkinsBase):
         """
         return jobname in self.jobs
 
+    def __delitem__(self, job_name):
+        del self.jobs[job_name]
+
     def get_node(self, nodename):
         """Get a node object for a specific node"""
         return self.get_nodes()[nodename]
