@@ -127,7 +127,7 @@ class Job(JenkinsBase, MutableJenkinsThing):
         return self._element_tree
 
     def get_build_triggerurl(self):
-        if not self.get_params_list():
+        if not self.has_params():
             return "%s/build" % self.baseurl
         return "%s/buildWithParameters" % self.baseurl
 
@@ -415,10 +415,10 @@ class Job(JenkinsBase, MutableJenkinsThing):
         scm = self._scm_map.get(scm_class)
         if not scm:
             raise NotSupportSCM(
-                "SCM class \"%s\" not supported by API, job \"%s\"" % (scm_class, self.name))
+                "SCM class \"%s\" not supported by API for job \"%s\"" % (scm_class, self.name))
         if scm == 'NullSCM':
             raise NotConfiguredSCM(
-                "SCM does not configured, job \"%s\"" % self.name)
+                "SCM is not configured for job \"%s\"" % self.name)
         return scm
 
     def get_scm_url(self):
@@ -603,10 +603,10 @@ class Job(JenkinsBase, MutableJenkinsThing):
         """
         Gets the list of parameter names for this job.
         """
-        params = []
-        for param in self.get_params():
-            params.append(param['name'])
-        return params
+        return [param['name'] for param in self.get_params()]
+
+    def has_params(self):
+        return len(self._data['actions']) > 0
 
     def has_queued_build(self, build_params):
         """Returns True if a build with build_params is currently queued."""
