@@ -1,9 +1,14 @@
+"""
+Module for jenkinsapi Node class
+"""
+
 from jenkinsapi.jenkinsbase import JenkinsBase
 import logging
 import urllib
 
 log = logging.getLogger(__name__)
 
+
 class Node(JenkinsBase):
     """
     Class to hold information on nodes that are attached as slaves to the master jenkins instance
@@ -27,9 +32,6 @@ class Node(JenkinsBase):
     def __str__(self):
         return self.name
 
-    def get_node_data(self):
-        return self._data
-
     def is_online(self):
         self.poll()
         return not self._data['offline']
@@ -44,27 +46,25 @@ class Node(JenkinsBase):
     def is_idle(self):
         return self._data['idle']
 
-
     def set_online(self):
-        """ 
+        """
         Set node online.
-        Before change state verify client state: if node set 'offline' but 'temporarilyOffline' 
+        Before change state verify client state: if node set 'offline' but 'temporarilyOffline'
         is not set - client has connection problems and AssertionError raised.
         If after run node state has not been changed raise AssertionError.
         """
         self.poll()
         # Before change state check if client is connected
         if self._data['offline'] and not self._data['temporarilyOffline']:
-            raise AssertionError("Node is offline and not marked as temporarilyOffline" + 
-                                 ", check client connection: " + 
-                                 "offline = %s , temporarilyOffline = %s" % 
-                                (self._data['offline'], self._data['temporarilyOffline']))
+            raise AssertionError("Node is offline and not marked as temporarilyOffline" +
+                                 ", check client connection: " +
+                                 "offline = %s , temporarilyOffline = %s" %
+                                 (self._data['offline'], self._data['temporarilyOffline']))
         elif self._data['offline'] and self._data['temporarilyOffline']:
             self.toggle_temporarily_offline()
-            self.poll()
             if self._data['offline']:
-                raise AssertionError("The node state is still offline, check client connection:" + 
-                                     " offline = %s , temporarilyOffline = %s" % 
+                raise AssertionError("The node state is still offline, check client connection:" +
+                                     " offline = %s , temporarilyOffline = %s" %
                                      (self._data['offline'], self._data['temporarilyOffline']))
 
     def set_offline(self, message="requested from jenkinsapi"):
@@ -73,13 +73,12 @@ class Node(JenkinsBase):
         If after run node state has not been changed raise AssertionError.
         : param message: optional string explain why you are taking this node offline
         """
-        self.poll()
         if not self._data['offline']:
             self.toggle_temporarily_offline(message)
             self.poll()
             if not self._data['offline']:
-                raise AssertionError("The node state is still online:" + 
-                                     "offline = %s , temporarilyOffline = %s" % 
+                raise AssertionError("The node state is still online:" +
+                                     "offline = %s , temporarilyOffline = %s" %
                                      (self._data['offline'], self._data['temporarilyOffline']))
 
     def toggle_temporarily_offline(self, message="requested from jenkinsapi"):
@@ -90,7 +89,9 @@ class Node(JenkinsBase):
         """
         initial_state = self.is_temporarily_offline()
         url = self.baseurl + "/toggleOffline?offlineMessage=" + urllib.quote(message)
-        html_result = self.hit_url(url)
+        html_result = self.jenkins.requester.get_and_confirm_status(url)
+        self.poll()
         log.debug(html_result)
-        if initial_state == self.is_temporarily_offline():
+        state = self.is_temporarily_offline()
+        if initial_state == state:
             raise AssertionError("The node state has not changed: temporarilyOffline = %s" % state)
