@@ -1,4 +1,7 @@
-import urllib
+"""
+jenkinsapi plugins
+"""
+
 import logging
 
 from jenkinsapi.jenkinsbase import JenkinsBase
@@ -9,6 +12,9 @@ log = logging.getLogger(__name__)
 
 
 class Plugins(JenkinsBase):
+    """
+    Plugins class for jenkinsapi
+    """
     def __init__(self, url, jenkins_obj):
         self.jenkins_obj = jenkins_obj
         JenkinsBase.__init__(self, url)
@@ -30,9 +36,7 @@ class Plugins(JenkinsBase):
         return [a[1] for a in self.iteritems()]
 
     def _get_plugins(self):
-        if not 'plugins' in self._data:
-            pass
-        else:
+        if 'plugins' in self._data:
             for p_dict in self._data["plugins"]:
                 yield p_dict["shortName"], Plugin(p_dict)
 
@@ -51,3 +55,6 @@ class Plugins(JenkinsBase):
         """
         return plugin_name in self.keys()
 
+    def __str__(self):
+        plugins = [plugin["shortName"] for plugin in self._data.get("plugins", [])]
+        return str(sorted(plugins))
